import { Component } from '@angular/core';
import {DictionaryPipe} from "../../../pipes/common/dictionary.pipe";
import {DatePipe, NgForOf, NgIf} from "@angular/common";
import {NzButtonComponent} from "ng-zorro-antd/button";
import {
  NzCellFixedDirective,
  NzTableCellDirective,
  NzTableComponent, NzTableModule,
  NzTbodyComponent,
  NzTdAddOnComponent, NzTheadComponent, NzThMeasureDirective, NzThSelectionComponent, NzTrDirective
} from "ng-zorro-antd/table";
import {NzColDirective, NzRowDirective} from "ng-zorro-antd/grid";
import {NzFlexDirective} from "ng-zorro-antd/flex";
import {NzFormControlComponent, NzFormDirective, NzFormItemComponent, NzFormLabelComponent} from "ng-zorro-antd/form";
import {NzInputDirective} from "ng-zorro-antd/input";
import {NzInputNumberComponent, NzInputNumberModule} from "ng-zorro-antd/input-number";
import {NzModalComponent, NzModalModule, NzModalService} from "ng-zorro-antd/modal";
import {NzOptionComponent, NzSelectComponent} from "ng-zorro-antd/select";
import {NzTypographyComponent} from "ng-zorro-antd/typography";
import {FormGroup, FormsModule, NonNullableFormBuilder, ReactiveFormsModule, Validators} from "@angular/forms";
import {MerService} from "../../../services/merchant/mer.service";
import {NzMessageService} from "ng-zorro-antd/message";
import {AgentPriceService} from "../../../services/agent/agent-price.service";
import {AgentMerService} from "../../../services/agent/agent-mer.service";
import {CommonService} from "../../../services/common/common.service";
import {NzDividerComponent} from "ng-zorro-antd/divider";
import {NzDropDownADirective, NzDropDownDirective, NzDropdownMenuComponent} from "ng-zorro-antd/dropdown";
import {NzIconDirective} from "ng-zorro-antd/icon";
import {NzMenuDirective, NzMenuItemComponent} from "ng-zorro-antd/menu";
import {NzDescriptionsModule} from "ng-zorro-antd/descriptions";
import {NzUploadComponent} from "ng-zorro-antd/upload";
import {NzAvatarModule} from "ng-zorro-antd/avatar";
import {NzImageModule} from "ng-zorro-antd/image";
import {NzSwitchComponent} from "ng-zorro-antd/switch";
import {NzDatePickerComponent} from "ng-zorro-antd/date-picker";
import {AgentService} from "../../../services/agent/agent.service";
import {AgentStaffService} from "../../../services/agent/agent-staff.service";

@Component({
  selector: 'app-agent-refer-price-list',
  standalone: true,
  imports: [
    DatePipe,
    DictionaryPipe,
    FormsModule,
    NgForOf,
    NgIf,
    NzButtonComponent,
    NzCellFixedDirective,
    NzColDirective,
    NzDividerComponent,
    NzDropDownADirective,
    NzDropDownDirective,
    NzDropdownMenuComponent,
    NzFormControlComponent,
    NzFormDirective,
    NzFormItemComponent,
    NzFormLabelComponent,
    NzIconDirective,
    NzInputDirective,
    NzMenuDirective,
    NzMenuItemComponent,
    NzOptionComponent,
    NzRowDirective,
    NzSelectComponent,
    NzTableCellDirective,
    NzTableComponent,
    NzTbodyComponent,
    NzThMeasureDirective,
    NzTheadComponent,
    NzTrDirective,
    ReactiveFormsModule,
    NzTableModule,
    NzModalModule,
    NzFlexDirective,
    NzDescriptionsModule,
    NzUploadComponent,
    NzAvatarModule,
    NzImageModule,
    NzSwitchComponent,
    NzDatePickerComponent,
    NzInputNumberModule,
    NzTypographyComponent
  ],
  templateUrl: './agent-refer-price-list.component.html',
  styleUrl: './agent-refer-price-list.component.less'
})
export class AgentReferPriceListComponent {
  // 表单页数
  tablePageNum = 1;
  // 每页数量
  tablePageSize = 10;
  // 表单数据
  tableData: any = {
    total: 0,
    list: [],
  };
  // 搜索表单
  searchForm: FormGroup;
  // 油站来源
  merSourceTypeArray = new DictionaryPipe().getDictionaryList('MER_SOURCE_TYPE');
  // 油号
  oilNoArray = new DictionaryPipe().getDictionaryList('OIL_NO');
  // 地区数据
  regionData: any = [];
  // 代理商
  agentData: any = [];
  // 代理商业务员
  agentStaffData: any = [];

  constructor(private fb: NonNullableFormBuilder,
              private merService: MerService,
              private message: NzMessageService,
              private agentService: AgentService,
              private agentStaffService: AgentStaffService,
              private agentPriceService: AgentPriceService,
              private agentMerService: AgentMerService,
              private commonService: CommonService,
              private modal: NzModalService) {
    // 初始化搜索框
    this.searchForm = this.fb.group({
      agentId: [''],
      agentStaffId: [''],
      sourceType: [''],
      provinceCode: [''],
      oilNo: [''],
      merNo: [''],
      merName: [''],
    });

    // 获取地区
    this.commonService.getRegion("", (data: any) => {
      this.regionData = data['return_data'];
    });

    // 获取代理商
    this.agentService.queryAgentList({type:'1',pageNum:1,pageSize:999}, (data: any) => {
      this.agentData = data['return_data']['list'];
      this.searchForm.controls['agentId'].setValue(String(this.agentData[0]['id']));
      // 查询业务员
      this.queryAgentStaff(String(this.agentData[0]['id']));
    });
  }

  /**
   * 获取数据
   */
  queryData() {
    this.searchForm.value.pageNum = this.tablePageNum;
    this.searchForm.value.pageSize = this.tablePageSize;
    this.agentPriceService.getPriceList(this.searchForm.value, (data: any) => {
      if (data['return_code'] == '000000') {
        this.tableData = data['return_data'];
      }
    });
  }

  /**
   * 获取数据
   */
  queryAgentStaff(agentId: string) {
    this.searchForm.controls['agentStaffId'].setValue(null);
    this.agentStaffService.getStaffList({agentId: agentId, pageNum:1, pageSize:9999}, (data: any) => {
      if (data['return_code'] == '000000') {
        this.agentStaffData = data['return_data']['list'];
        if (this.agentStaffData.length > 0) {
          this.searchForm.controls['agentStaffId'].setValue(''+this.agentStaffData[0]['id']);
          // 查询数据
          this.queryData();
        }
      }
    });
  }

  /**
   * 搜索表单提交
   */
  searchFormSubmit(): void {
    this.tablePageNum = 1;
    this.queryData();
  }

  /**
   * 搜索表单重置
   */
  searchFormReset(): void {
    this.searchForm.controls['provinceCode'].setValue(null);
    this.searchForm.controls['sourceType'].setValue(null);
    this.searchForm.controls['merNo'].setValue(null);
    this.searchForm.controls['merName'].setValue(null);
    this.searchForm.controls['oilNo'].setValue(null);
  }
}
