import { Component } from '@angular/core';
import {DatePipe, NgForOf, NgIf} from "@angular/common";
import {DictionaryPipe} from "../../../pipes/common/dictionary.pipe";
import {FormGroup, FormsModule, NonNullableFormBuilder, ReactiveFormsModule, Validators} from "@angular/forms";
import {NzButtonComponent} from "ng-zorro-antd/button";
import {
  NzCellFixedDirective,
  NzTableCellDirective,
  NzTableComponent, NzTableModule,
  NzTbodyComponent, NzTheadComponent,
  NzThMeasureDirective, NzTrDirective
} from "ng-zorro-antd/table";
import {NzColDirective, NzRowDirective} from "ng-zorro-antd/grid";
import {NzDividerComponent} from "ng-zorro-antd/divider";
import {NzDropDownADirective, NzDropDownDirective, NzDropdownMenuComponent} from "ng-zorro-antd/dropdown";
import {NzFlexDirective} from "ng-zorro-antd/flex";
import {NzFormControlComponent, NzFormDirective, NzFormItemComponent, NzFormLabelComponent} from "ng-zorro-antd/form";
import {NzIconDirective} from "ng-zorro-antd/icon";
import {NzInputDirective} from "ng-zorro-antd/input";
import {NzInputNumberModule} from "ng-zorro-antd/input-number";
import {NzMenuDirective, NzMenuItemComponent} from "ng-zorro-antd/menu";
import {NzModalModule, NzModalService} from "ng-zorro-antd/modal";
import {DeviceService} from "../../../services/device/device.service";
import {NzMessageService} from "ng-zorro-antd/message";
import {NzOptionComponent, NzSelectComponent} from "ng-zorro-antd/select";
import {NzDescriptionsModule} from "ng-zorro-antd/descriptions";
import {NzUploadComponent} from "ng-zorro-antd/upload";
import {NzAvatarModule} from "ng-zorro-antd/avatar";
import {NzImageModule} from "ng-zorro-antd/image";
import {NzSwitchComponent} from "ng-zorro-antd/switch";
import {NzDatePickerComponent} from "ng-zorro-antd/date-picker";
import {DATA} from "../../../data/login/localStorage.namespace";
import {BrowserStorageService} from "../../../utils/localStorage.service";

@Component({
  selector: 'app-device-list',
  standalone: true,
  imports: [
    DatePipe,
    DictionaryPipe,
    FormsModule,
    NgForOf,
    NgIf,
    NzButtonComponent,
    NzCellFixedDirective,
    NzColDirective,
    NzDividerComponent,
    NzDropDownADirective,
    NzDropDownDirective,
    NzDropdownMenuComponent,
    NzFormControlComponent,
    NzFormDirective,
    NzFormItemComponent,
    NzFormLabelComponent,
    NzIconDirective,
    NzInputDirective,
    NzMenuDirective,
    NzMenuItemComponent,
    NzOptionComponent,
    NzRowDirective,
    NzSelectComponent,
    NzTableCellDirective,
    NzTableComponent,
    NzTbodyComponent,
    NzThMeasureDirective,
    NzTheadComponent,
    NzTrDirective,
    ReactiveFormsModule,
    NzTableModule,
    NzModalModule,
    NzFlexDirective,
    NzDescriptionsModule,
    NzUploadComponent,
    NzAvatarModule,
    NzImageModule,
    NzSwitchComponent,
    NzDatePickerComponent,
    NzInputNumberModule
  ],
  templateUrl: './device-list.component.html',
  styleUrl: './device-list.component.less'
})
export class DeviceListComponent {
  // 表单页数
  tablePageNum = 1;
  // 每页数量
  tablePageSize = 10;
  // 表单数据
  tableData: any = {
    total: 0,
    list: [],
  };
  accountType = null;
  // 搜索表单
  searchForm: FormGroup;
  // 编辑设备表单
  editDeviceForm: FormGroup;
  // 编辑设备模态框
  editDeviceModal = false;
  // 油站来源
  typeArray = new DictionaryPipe().getDictionaryList('DEVICE_TYPE');
  constructor(private fb: NonNullableFormBuilder,
              private message: NzMessageService,
              private storage: BrowserStorageService,
              private deviceService: DeviceService,
              private modal: NzModalService) {
    this.accountType = this.storage.get(DATA)['account']['objectType'];

    // 初始化搜索框
    this.searchForm = this.fb.group({
      type: [''],
      merNo: [''],
      merName: [''],
      deviceSn: [''],
    });

    this.editDeviceForm = this.fb.group({
      id: [null],
      type: [null, [Validators.required]],
      merNo: [null],
      deviceSn: [null, [Validators.required]],
      deviceKey: [null, [Validators.required]],
    });

    // 查询数据
    this.queryData();
  }

  /**
   * 获取数据
   */
  queryData() {
    this.searchForm.value.pageNum = this.tablePageNum;
    this.searchForm.value.pageSize = this.tablePageSize;
    this.searchForm.value.time = new Date().getTime();
    this.deviceService.getDeviceList(this.searchForm.value, (data: any) => {
      if (data['return_code'] == '000000') {
        this.tableData = data['return_data'];
      }
    });
  }

  /**
   * 搜索表单提交
   */
  searchFormSubmit(): void {
    this.tablePageNum = 1;
    this.queryData();
  }

  /**
   * 搜索表单重置
   */
  searchFormReset(): void {
    this.searchForm.reset();
  }

  /**
   * 删除设备
   * @param deviceId
   */
  delDevice(deviceId: number) {
    this.modal.confirm({
      nzTitle: '提示',
      nzContent: '确定删除设备吗？',
      nzOnOk: () =>
        this.deviceService.delDevice({deviceId: deviceId}, (data: any) => {
          if (data['return_code'] == '000000') {
            // 刷新数据
            this.queryData();
            this.message.create('success', '操作成功');
          } else {
            this.message.create('error', data['return_msg']);
          }
        })
    });
  }

  /**
   * 打开编辑设备模态框
   * @param data
   */
  showEditDeviceModal(data: any) {
    if (data != null) {
      data['type'] = ''+data['type'];
      this.editDeviceForm.patchValue(data);
    }
    this.editDeviceModal = true;
  }

  /**
   * 提交数据
   */
  submitData() {
    if (this.accountType != 2) {
      this.message.create('error', '只有油站角色才能绑定设备');
      return;
    }
    if (this.editDeviceForm.controls['merNo'].value == null) {
      this.editDeviceForm.controls['merNo'].setValue(this.storage.get(DATA)['merchant']['merNo']);
    }
    if (this.editDeviceForm.valid) {
      let param = this.editDeviceForm.value;
      this.deviceService.editDevice(param, (data: any) => {
        if (data['return_code'] == '000000') {
          this.message.create('success', '操作成功');
          // 查询数据
          this.queryData();
          // 关闭弹窗
          this.closeEditDeviceModal();
        } else {
          this.message.create('error', data['return_msg']);
        }
      });
    } else {
      Object.values(this.editDeviceForm.controls).forEach(control => {
        if (control.invalid) {
          control.markAsDirty();
          control.updateValueAndValidity({ onlySelf: true });
        }
      });
    }
  }

  /**
   * 关闭编辑设备模态框
   */
  closeEditDeviceModal() {
    this.editDeviceForm.reset();
    this.editDeviceModal = false;
  }
}
