import { Component } from '@angular/core';
import {FormGroup, FormsModule, NonNullableFormBuilder, ReactiveFormsModule, Validators} from "@angular/forms";
import {DictionaryPipe} from "../../../pipes/common/dictionary.pipe";
import {NzMessageService} from "ng-zorro-antd/message";
import {BrowserStorageService} from "../../../utils/localStorage.service";
import {NzModalModule, NzModalService} from "ng-zorro-antd/modal";
import {DATA} from "../../../data/login/localStorage.namespace";
import {DatePipe, NgForOf, NgIf} from "@angular/common";
import {NzButtonComponent} from "ng-zorro-antd/button";
import {
  NzCellFixedDirective,
  NzTableCellDirective,
  NzTableComponent, NzTableModule,
  NzTbodyComponent, NzTheadComponent,
  NzThMeasureDirective, NzTrDirective
} from "ng-zorro-antd/table";
import {NzColDirective, NzRowDirective} from "ng-zorro-antd/grid";
import {NzDividerComponent} from "ng-zorro-antd/divider";
import {NzDropDownADirective, NzDropDownDirective, NzDropdownMenuComponent} from "ng-zorro-antd/dropdown";
import {NzFormControlComponent, NzFormDirective, NzFormItemComponent, NzFormLabelComponent} from "ng-zorro-antd/form";
import {NzIconDirective} from "ng-zorro-antd/icon";
import {NzInputDirective} from "ng-zorro-antd/input";
import {NzMenuDirective, NzMenuItemComponent} from "ng-zorro-antd/menu";
import {NzOptionComponent, NzSelectComponent} from "ng-zorro-antd/select";
import {NzFlexDirective} from "ng-zorro-antd/flex";
import {NzDescriptionsModule} from "ng-zorro-antd/descriptions";
import {NzUploadComponent} from "ng-zorro-antd/upload";
import {NzAvatarModule} from "ng-zorro-antd/avatar";
import {NzImageModule} from "ng-zorro-antd/image";
import {NzSwitchComponent} from "ng-zorro-antd/switch";
import {NzDatePickerComponent} from "ng-zorro-antd/date-picker";
import {NzInputNumberModule} from "ng-zorro-antd/input-number";
import {DiscountService} from "../../../services/discount/discount.service";
import {RouterLink} from "@angular/router";
import {NzTypographyComponent} from "ng-zorro-antd/typography";
import {MerService} from "../../../services/merchant/mer.service";
import {CommonService} from "../../../services/common/common.service";
import {DiscountStockComponent} from "../discount-stock/discount-stock.component";

@Component({
  selector: 'app-discount-list',
  standalone: true,
  imports: [
    DatePipe,
    DictionaryPipe,
    FormsModule,
    NgForOf,
    NgIf,
    NzButtonComponent,
    NzCellFixedDirective,
    NzColDirective,
    NzDividerComponent,
    NzDropDownADirective,
    NzDropDownDirective,
    NzDropdownMenuComponent,
    NzFormControlComponent,
    NzFormDirective,
    NzFormItemComponent,
    NzFormLabelComponent,
    NzIconDirective,
    NzInputDirective,
    NzMenuDirective,
    NzMenuItemComponent,
    NzOptionComponent,
    NzRowDirective,
    NzSelectComponent,
    NzTableCellDirective,
    NzTableComponent,
    NzTbodyComponent,
    NzThMeasureDirective,
    NzTheadComponent,
    NzTrDirective,
    ReactiveFormsModule,
    NzTableModule,
    NzModalModule,
    NzFlexDirective,
    NzDescriptionsModule,
    NzUploadComponent,
    NzAvatarModule,
    NzImageModule,
    NzSwitchComponent,
    NzDatePickerComponent,
    NzInputNumberModule,
    RouterLink,
    NzTypographyComponent,
    DiscountStockComponent
  ],
  templateUrl: './discount-list.component.html',
  styleUrl: './discount-list.component.less'
})
export class DiscountListComponent {
  // 表单页数
  tablePageNum = 1;
  // 每页数量
  tablePageSize = 10;
  // 表单数据
  tableData: any = {
    total: 0,
    list: [],
  };
  accountType = null;
  // 搜索表单
  searchForm: FormGroup;
  // 优惠券类型
  discountTypeArray = new DictionaryPipe().getDictionaryList('DISCOUNT_TYPE');
  // 优惠券状态
  discountStatusArray = new DictionaryPipe().getDictionaryList('DISCOUNT_STATUS');
  // 油站来源
  merSourceTypeArray = new DictionaryPipe().getDictionaryList('MER_SOURCE_TYPE');
  // 赠送用户模态框
  giveUserModal = false;
  giveUserForm: FormGroup;

  regionData: any = []
  // 可用油站
  usableMerModal = false;
  discountNo: any = null;
  // 分配油站模态框
  assignMerModal = false;
  assignMerData: any = [];
  assignSearchForm: FormGroup;
  // 表单页数
  assignTablePageNum = 1;
  // 每页数量
  assignTablePageSize = 10;
  // 表单数据
  assignTableData: any = {
    total: 0,
    list: [],
  };
  // 列表中全选状态
  checked = false;
  // 已选择的数据
  setOfCheckedId = new Set<string>();

  // 库存模态框
  stockModal = false;
  constructor(private fb: NonNullableFormBuilder,
              private message: NzMessageService,
              private storage: BrowserStorageService,
              private discountService: DiscountService,
              private commonService: CommonService,
              private merService: MerService,
              private modal: NzModalService) {
    this.accountType = this.storage.get(DATA)['account']['objectType'];
    // 获取地区
    this.commonService.getRegion("", (data: any) => {
      this.regionData = data['return_data'];
    });

    // 初始化搜索框
    this.searchForm = this.fb.group({
      discountNo: [''],
      discountName: [''],
      discountType: [''],
      status: [''],
    });
    // 初始化搜索框
    this.assignSearchForm = this.fb.group({
      sourceType: [''],
      provinceCode: [''],
      merNo: [''],
      merName: [''],
      status: [''],
    });

    this.giveUserForm = this.fb.group({
      discountNo: [''],
      discountName: [''],
      userPhone: [null, [Validators.required]],
      number: [1, [Validators.required]]
    });
    // 查询数据
    this.queryData();
  }

  /**
   * 获取数据
   */
  queryData() {
    this.searchForm.value.pageNum = this.tablePageNum;
    this.searchForm.value.pageSize = this.tablePageSize;
    this.searchForm.value.time = new Date().getTime();
    this.discountService.queryList(this.searchForm.value, (data: any) => {
      if (data['return_code'] == '000000') {
        this.tableData = data['return_data'];
      }
    });
  }

  /**
   * 搜索表单提交
   */
  searchFormSubmit(): void {
    this.tablePageNum = 1;
    this.queryData();
  }

  /**
   * 搜索表单重置
   */
  searchFormReset(): void {
    this.searchForm.reset();
  }

  /**
   * 上线
   * @param deviceId
   */
  online(discountNo: number) {
    this.modal.confirm({
      nzTitle: '提示',
      nzContent: '确定发布优惠券吗？',
      nzOnOk: () =>
        this.discountService.online({discountNo: discountNo}, (data: any) => {
          if (data['return_code'] == '000000') {
            // 刷新数据
            this.queryData();
            this.message.create('success', '操作成功');
          } else {
            this.message.create('error', data['return_msg']);
          }
        })
    });
  }
  /**
   * 下线优惠券
   * @param deviceId
   */
  done(discountNo: number) {
    this.modal.confirm({
      nzTitle: '提示',
      nzContent: '确定优惠券下线吗？',
      nzOnOk: () =>
        this.discountService.done({discountNo: discountNo}, (data: any) => {
          if (data['return_code'] == '000000') {
            // 刷新数据
            this.queryData();
            this.message.create('success', '操作成功');
          } else {
            this.message.create('error', data['return_msg']);
          }
        })
    });
  }

  /**
   * 删除
   * @param deviceId
   */
  delData(discountNo: number) {
    this.modal.confirm({
      nzTitle: '提示',
      nzContent: '确定删除吗？',
      nzOnOk: () =>
        this.discountService.delete({discountNo: discountNo}, (data: any) => {
          if (data['return_code'] == '000000') {
            // 刷新数据
            this.queryData();
            this.message.create('success', '操作成功');
          } else {
            this.message.create('error', data['return_msg']);
          }
        })
    });
  }

  /**
   * 打开赠送用户模态框
   * @param data
   */
  showGiveUser(data: any) {
    this.giveUserForm.patchValue({discountNo: data.discountNo, discountName: data.discountName});
    this.giveUserForm.controls['discountNo'].disable();
    this.giveUserForm.controls['discountName'].disable();
    this.giveUserModal = true;
  }
  /**
   * 赠送确认框
   */
  submitGiveUserConfirm() {
    this.modal.confirm({
      nzTitle: '提示',
      nzContent: '确定赠送吗？',
      nzOnOk: () => this.submitGiveUser()
    });
  }
  /**
   * 提交赠送用户
   */
  submitGiveUser() {
    if (this.giveUserForm.valid) {
      const param = this.giveUserForm.value;
      param['discountNo'] = this.giveUserForm.controls['discountNo'].value;
      this.discountService.giveUser(param, (data: any) => {
        if (data['return_code'] == '000000') {
          this.message.create('success', '操作成功');
        } else {
          this.message.create('error', data['return_msg']);
        }
      });
    } else {
      Object.values(this.giveUserForm.controls).forEach(control => {
        if (control.invalid) {
          control.markAsDirty();
          control.updateValueAndValidity({ onlySelf: true });
        }
      });
    }
  }

  /**
   * 关闭赠送用户模态框
   */
  closeGiveUser() {
    this.giveUserForm.reset();
    this.giveUserForm.controls['discountNo'].enable();
    this.giveUserForm.controls['discountName'].enable();
    this.giveUserModal = false;
  }

  /**
   * 打开可用油站
   */
  showUsableMerModal(discountNo: any) {
    // 清除已勾选数据
    this.setOfCheckedId.clear();

    this.discountNo = discountNo;
    this.discountService.getUseMerList({discountNo: discountNo}, (data: any) => {
      if (data['return_code'] == '000000') {
        // 刷新数据
        this.assignMerData = data['return_data'];
      } else {
        this.message.create('error', data['return_msg']);
      }
    })
    this.usableMerModal = true;
  }

  /**
   * 关闭可用油站
   */
  closeUsableMerModal() {
    this.usableMerModal = false;
  }

  /**
   * 打开分配油站
   * @param discountNo
   */
  showAssignMer() {
    this.queryMer();
    this.assignMerModal = true;
  }

  submitAssignMer() {
    let param = {
      discountNo: this.discountNo,
      merNoList: Array.from(this.setOfCheckedId)
    }
    this.discountService.editUseMer(param, (data: any) => {
      if (data['return_code'] == '000000') {
        this.showUsableMerModal(this.discountNo);
        this.closeAssignMer();
      } else {
        this.message.create('error', data['return_msg']);
      }
    })
  }
  /**
   * 查询油站列表
   */
  queryMer() {
    this.assignSearchForm.value.pageNum = this.assignTablePageNum;
    this.assignSearchForm.value.pageSize = this.assignTablePageSize;
    this.merService.queryMerList(this.assignSearchForm.value, (data: any) => {
      if (data['return_code'] == '000000') {
        this.assignTableData = data['return_data'];
        for (let item of this.assignMerData) {
          this.updateCheckedSet(item.merNo, true);
        }
        this.refreshCheckedStatus();
      }
    });
  }

  /**
   * 关闭分配油站
   */
  closeAssignMer() {
    this.assignMerModal = false;
  }

  updateCheckedSet(merNo: string, checked: boolean): void {
    if (checked) {
      this.setOfCheckedId.add(merNo);
    } else {
      this.setOfCheckedId.delete(merNo);
    }
  }

  /**
   * 单选
   * @param merNo
   * @param checked
   */
  onItemChecked(merNo: string, checked: boolean): void {
    this.updateCheckedSet(merNo, checked);
    this.refreshCheckedStatus();
  }

  /**
   * 全选
   * @param checked
   */
  onAllChecked(checked: boolean): void {
    // @ts-ignore
    this.assignTableData.list.forEach(({ merNo }) => this.updateCheckedSet(merNo, checked));
    this.refreshCheckedStatus();
  }

  /**
   * 刷新数据
   */
  refreshCheckedStatus(): void {
    // @ts-ignore
    this.checked = this.assignTableData.list.every(({ merNo }) => this.setOfCheckedId.has(merNo));
  }

  /**
   * 打开库存模态框
   * @param discountNo
   */
  showStockModal(discountNo: any) {
      this.discountNo =  discountNo;
      this.stockModal = true;
  }

  /**
   * 关闭库存模态框
   */
  closeStockModal() {
    this.stockModal = false;
  }
}
