import { Component } from '@angular/core';
import {DatePipe, NgForOf, NgIf} from "@angular/common";
import {NzButtonComponent} from "ng-zorro-antd/button";
import {
  NzCellFixedDirective,
  NzTableCellDirective,
  NzTableComponent, NzTableModule,
  NzTbodyComponent, NzTheadComponent,
  NzThMeasureDirective, NzTrDirective
} from "ng-zorro-antd/table";
import {NzColDirective, NzRowDirective} from "ng-zorro-antd/grid";
import {NzDropDownADirective, NzDropDownDirective, NzDropdownMenuComponent} from "ng-zorro-antd/dropdown";
import {NzFormControlComponent, NzFormDirective, NzFormItemComponent, NzFormLabelComponent} from "ng-zorro-antd/form";
import {NzIconDirective} from "ng-zorro-antd/icon";
import {NzInputDirective} from "ng-zorro-antd/input";
import {NzMenuDirective, NzMenuItemComponent} from "ng-zorro-antd/menu";
import {NzModalComponent, NzModalModule, NzModalService} from "ng-zorro-antd/modal";
import {NzWaveDirective} from "ng-zorro-antd/core/wave";
import {FormBuilder, FormGroup, FormsModule, ReactiveFormsModule, Validators} from "@angular/forms";
import {NzMessageService} from "ng-zorro-antd/message";
import {MerClassGroupService} from "../../../services/merchant/mer-class-group.service";
import {DictionaryPipe} from "../../../pipes/common/dictionary.pipe";
import {NzDividerComponent} from "ng-zorro-antd/divider";
import {NzOptionComponent, NzSelectComponent} from "ng-zorro-antd/select";
import {NzFlexDirective} from "ng-zorro-antd/flex";
import {NzDescriptionsModule} from "ng-zorro-antd/descriptions";
import {NzUploadComponent} from "ng-zorro-antd/upload";
import {NzAvatarModule} from "ng-zorro-antd/avatar";
import {NzImageModule} from "ng-zorro-antd/image";
import {NzSwitchComponent} from "ng-zorro-antd/switch";
import {NzDatePickerComponent, NzRangePickerComponent} from "ng-zorro-antd/date-picker";
import {NzRadioButtonDirective, NzRadioComponent, NzRadioGroupComponent} from "ng-zorro-antd/radio";
import {NzToolTipModule} from "ng-zorro-antd/tooltip";
import {NzTabsModule} from "ng-zorro-antd/tabs";
import {NzTagModule} from "ng-zorro-antd/tag";
import {NzCardModule} from "ng-zorro-antd/card";
import {NzInputNumberModule} from "ng-zorro-antd/input-number";
import {NzQRCodeModule} from "ng-zorro-antd/qr-code";
import {RouterLink} from "@angular/router";

@Component({
  selector: 'app-mer-class-group-list',
  standalone: true,
  imports: [
    DatePipe,
    DictionaryPipe,
    FormsModule,
    NgForOf,
    NgIf,
    NzButtonComponent,
    NzCellFixedDirective,
    NzColDirective,
    NzDividerComponent,
    NzDropDownADirective,
    NzDropDownDirective,
    NzDropdownMenuComponent,
    NzFormControlComponent,
    NzFormDirective,
    NzFormItemComponent,
    NzFormLabelComponent,
    NzIconDirective,
    NzInputDirective,
    NzMenuDirective,
    NzMenuItemComponent,
    NzOptionComponent,
    NzRowDirective,
    NzSelectComponent,
    NzTableCellDirective,
    NzTableComponent,
    NzTbodyComponent,
    NzThMeasureDirective,
    NzTheadComponent,
    NzTrDirective,
    ReactiveFormsModule,
    NzTableModule,
    NzModalModule,
    NzFlexDirective,
    NzDescriptionsModule,
    NzUploadComponent,
    NzAvatarModule,
    NzImageModule,
    NzSwitchComponent,
    NzDatePickerComponent,
    NzRadioButtonDirective,
    NzRadioComponent,
    NzRadioGroupComponent,
    NzRangePickerComponent,
    NzToolTipModule,
    NzTabsModule,
    NzTagModule,
    NzCardModule,
    NzInputNumberModule,
    NzQRCodeModule,
    RouterLink
  ],
  templateUrl: './mer-class-group-list.component.html',
  styleUrl: './mer-class-group-list.component.less'
})
export class MerClassGroupListComponent {

  dataObject: any = {};
  tableLoading = true;
  searchForm: FormGroup;
  pageNum: number = 1;
  whereObject: any = {};

  classGroupModal = false;
  classGroupForm: FormGroup;

  constructor(private modal: NzModalService,
              private message: NzMessageService,
              private gasClassGroupService: MerClassGroupService,
              private form: FormBuilder) {
    this.searchForm = this.form.group({
      name: [null],
      principalName: [null],
      principalPhone: [null],
    });

    this.classGroupForm = this.form.group({
      id: [null],
      name: [null, [Validators.required]],
      principalName: [null, [Validators.required]],
      principalPhone: [null, [Validators.required]],
    });
    this.requestData(1);

  }

  /**
   * 请求数据
   */
  requestData(pageNum: number) {
    this.tableLoading = true;
    this.whereObject['pageNum'] = pageNum;
    this.whereObject['pageSize'] = 10;
    this.whereObject['time'] = new Date().getTime();
    this.gasClassGroupService.getClassGroupList(this.whereObject, (data: any) => {
      if (data['return_code'] === '000000') {
        this.dataObject = data['return_data'];
      } else {
        this.modal.error(data['return_msg']);
      }
      this.tableLoading = false;
    });
  }

  /**
   * 搜索
   * @param whereObject 条件
   */
  search(whereObject: object) {
    this.whereObject = whereObject;
    this.requestData(1);
  }

  /**
   * 重置
   */
  resetForm(): void {
    this.searchForm.reset();
  }

  /**
   * 弹出删除对话框
   */
  showDeleteConfirm(groupId: number): void {
    this.modal.confirm({
      nzTitle: '警告',
      nzContent: '是否删除班组',
      nzOkText: '是',
      nzCancelText: '否',
      nzOnOk: () => this.deleteData(groupId)
    });
  }

  /**
   * 删除数据
   *
   */
  deleteData(groupId: number) {
    this.gasClassGroupService.delClassGroup(groupId, (data: any) => {
      if (data['return_code'] === '000000') {
        this.requestData(this.whereObject['pageNum']);
      } else {
        this.modal.error({
          nzTitle: '提示',
          nzContent: data['return_msg']
        });
      }
    });
  }

  /**
   * 打开编辑班组模态框
   */
  showEditClassGroup(data: any) {
    if (data != null) {
      this.classGroupForm.patchValue(data);
    }
    this.classGroupModal = true;
  }

  /**
   * 关闭编辑班组模态框
   */
  closeEditClassGroup() {
    this.classGroupForm.reset();
    this.classGroupModal = false;
  }

  /**
   * 提交编辑班组
   */
  submitEditClassGroup(){
    for (const i in this.classGroupForm.controls) {
      this.classGroupForm.controls[i].markAsDirty();
      this.classGroupForm.controls[i].updateValueAndValidity();
    }
    if (this.classGroupForm.status == null || this.classGroupForm.status !== 'VALID') {
      this.modal.warning({
        nzTitle: '提示',
        nzContent: '请填写所有必填项',
      });
      return;
    }

    // 提交数据
    this.gasClassGroupService.editClassGroup(this.classGroupForm.value, (data: any) => {
      if (data['return_code'] === '000000') {
        this.modal.success({
          nzTitle: '提示',
          nzContent: '保存成功',
        });
        this.closeEditClassGroup();
        this.requestData(this.whereObject['pageNum']);
      } else {
        this.modal.warning({
          nzTitle: '提示',
          nzContent: data['return_msg'],
        });
      }
    });
  }
}
