import {Component} from '@angular/core';
import {NzModalModule, NzModalService} from "ng-zorro-antd/modal";
import {FormGroup, FormsModule, NonNullableFormBuilder, ReactiveFormsModule, Validators} from "@angular/forms";
import {NgForOf, NgIf} from "@angular/common";
import {NzButtonComponent} from "ng-zorro-antd/button";
import {NzColDirective} from "ng-zorro-antd/grid";
import {NzFlexDirective} from "ng-zorro-antd/flex";
import {
  NzFormControlComponent,
  NzFormDirective,
  NzFormItemComponent,
  NzFormLabelComponent,
  NzFormModule
} from "ng-zorro-antd/form";
import {NzInputDirective, NzInputGroupComponent} from "ng-zorro-antd/input";
import {NzOptionComponent, NzSelectComponent, NzSelectModule} from "ng-zorro-antd/select";
import {NzUploadFile, NzUploadModule} from "ng-zorro-antd/upload";
import {NzIconDirective} from "ng-zorro-antd/icon";
import {Observable, Observer} from "rxjs";
import {NzMessageService} from "ng-zorro-antd/message";
import {environment} from "../../../../environments/environment";
import {MerService} from "../../../services/merchant/mer.service";
import {RoleService} from "../../../services/role/role.service";
import {NzInputNumberComponent} from "ng-zorro-antd/input-number";
import {DomSanitizer} from "@angular/platform-browser";
import {DictionaryPipe} from "../../../pipes/common/dictionary.pipe";
import {CommonService} from "../../../services/common/common.service";
import {ActivatedRoute} from "@angular/router";
import {NzCascaderModule} from "ng-zorro-antd/cascader";
import {HttpClient} from "@angular/common/http";
import {MerChainBrandService} from "../../../services/merchant/mer-chain-brand.service";
@Component({
  selector: 'app-mer-add',
  standalone: true,
  imports: [
    FormsModule,
    NgForOf,
    NzButtonComponent,
    NzColDirective,
    NzFlexDirective,
    NzFormControlComponent,
    NzFormDirective,
    ReactiveFormsModule,
    NzFormItemComponent,
    NzFormLabelComponent,
    NzInputDirective,
    NzSelectComponent,
    NzOptionComponent,
    NzModalModule,
    NzFormModule,
    NzUploadModule,
    NzIconDirective,
    NgIf,
    NzInputGroupComponent,
    NzInputNumberComponent,
    NzCascaderModule
  ],
  templateUrl: './mer-add.component.html',
  styleUrl: './mer-add.component.less'
})
export class MerAddComponent {

  BASE_URL = environment.baseUrl;
  FILE_URL = environment.imageUrl;
  loading = false;
  logoUrl?: string;

  form: FormGroup;
  // 角色数据
  roleData: any = [];

  // 油价价区
  oilPriceZoneArray = new DictionaryPipe().getDictionaryList('OIL_PRICE_ZONE');
  // 商户连锁品牌结算类型
  merChainBrandSettleTypeArray = new DictionaryPipe().getDictionaryList('MER_CHAIN_BRAND_SETTLE_TYPE');
  // 地区数据
  regionData: any = [];
  // 商户连锁品牌数据
  merChainBrandData: any = [];
  // 商户来源
  merSourceType = 1;

  positioningModal = false;
  positioningObj: any = {};

  constructor(private fb: NonNullableFormBuilder,
              private merService: MerService,
              private merChainBrandService: MerChainBrandService,
              private roleService: RoleService,
              private message: NzMessageService,
              private activatedRoute: ActivatedRoute,
              private http: HttpClient) {
    // 初始化表单
    this.form = this.fb.group({
      merNo: [null],
      areaCode: [null],
      chainBrandId: [null],
      chainBrandSettleType: [null],
      merLogo: ['', [Validators.required]],
      region: [[], [Validators.required]],
      oilPriceZoneId: [''],
      merName: ['', [Validators.required]],
      contactsName: ['', [Validators.required]],
      contactsTel: ['', [Validators.required]],
      customerServiceTel: ['', [Validators.required]],
      address: ['', [Validators.required]],
      longitude: ['', [Validators.required]],
      latitude: ['', [Validators.required]],
      merLabel: [''],
    });

    this.activatedRoute.queryParams.subscribe(queryParams => {
      // 接收到路由参数
      if (queryParams['merNo'] != null) {
        // 查询详情
        this.merService.queryMer(queryParams['merNo'], (data: any) => {
          if (data['return_code'] == '000000') {
            this.form.controls['chainBrandId'].disable();
            this.form.controls['chainBrandSettleType'].disable();
            const merchant = data['return_data']['merchant'];
            // 处理油站图片
            if (merchant['merLogo'] != null && merchant['merLogo'] != '') {
              this.merSourceType = merchant['sourceType'];
              if (merchant['sourceType'] == 1) {
                this.logoUrl = this.FILE_URL + String(merchant['merLogo']);
              } else {
                this.logoUrl = String(merchant['merLogo']);
              }
            }
            // 处理油站价区
            merchant['region'] = [merchant['provinceCode'],merchant['cityCode'],merchant['areaCode']];
            // 处理油站价区
            if (merchant['oilPriceZoneId'] != null) {
              merchant['oilPriceZoneId'] = String(merchant['oilPriceZoneId']);
            }
            // 处理油站价区
            if (merchant['chainBrandId'] != null) {
              merchant['chainBrandId'] = String(merchant['chainBrandId']);
            }
            // 处理油站价区
            if (merchant['chainBrandSettleType'] != null) {
              merchant['chainBrandSettleType'] = String(merchant['chainBrandSettleType']);
            }
            // 处理油站标签
            if (merchant['merLabel'] != null && merchant['merLabel'] != '') {
              merchant['merLabel'] = String(merchant['merLabel']).split(',');
            }
            this.form.patchValue(merchant);
          }
        });
      }
    });

    // 获取地区数据
    this.http.get('assets/data/region.json').subscribe((data: any) => {
      this.regionData = data;
    });

    // 获取连锁品牌
    this.merChainBrandService.getList({pageNum:1,pageSize: 9999}, (data:any) =>{
       this.merChainBrandData = data['return_data']['list'];
    });

    // 获取角色数据
    this.roleService.queryAllRole((data: any) => {
      this.roleData = data['return_data'];
    });

    // 监听地址定位
    addEventListener('message', (event: any) => {
      // 接收位置信息，用户选择确认位置点后选点组件会触发该事件，回传用户的位置信息
      var loc = event.data;
      if (loc && loc.module == 'locationPicker') { // 防止其他应用也会向该页面post信息，需判断module是否为'locationPicker'
        this.positioningObj = loc;
        console.log(this.positioningObj);
      }
    }, false);
  }

  /**
   * 打开地图选择
   */
  showPositioning() {
    this.positioningModal = true;
  }

  /**
   * 确认选择地址
   */
  submitAddress() {
    this.form.controls['address'].setValue(this.positioningObj.poiaddress);
    this.form.controls['longitude'].setValue(this.positioningObj.latlng.lng);
    this.form.controls['latitude'].setValue(this.positioningObj.latlng.lat);
    this.positioningModal = false;
  }

  submitForm() {
    if (this.form.valid) {
      const param = this.form.value;
      if (param['merLabel'] != null && param['merLabel'].length > 0) {
        param['merLabel'] = param['merLabel'].join(',');
      }
      param['areaCode'] = param['region'][2];

      this.form.controls['chainBrandId'].enable();
      this.form.controls['chainBrandSettleType'].enable();
      this.merService.editMerchant(param, (data: any) => {
        if (data['return_code'] == '000000') {
          this.message.create('success', '操作成功');
          if (param['merNo'] == null) {
            // 清空表单
            this.form.reset();
            this.logoUrl = '';
          }
        } else {
          this.form.controls['chainBrandId'].disable();
          this.form.controls['chainBrandSettleType'].disable();
          this.message.create('error', data['return_msg']);
        }
      });
    } else {
      Object.values(this.form.controls).forEach(control => {
        if (control.invalid) {
          control.markAsDirty();
          control.updateValueAndValidity({ onlySelf: true });
        }
      });
    }
  }

  private getBase64(img: File, callback: (img: string) => void): void {
    const reader = new FileReader();
    reader.addEventListener('load', () => callback(reader.result!.toString()));
    reader.readAsDataURL(img);
  }

  handleChange(info: { file: NzUploadFile }): void {
    switch (info.file.status) {
      case 'uploading':
        this.loading = true;
        break;
      case 'done':
        // Get this url from response in real world.
        this.getBase64(info.file!.originFileObj!, (img: string) => {
          this.loading = false;
          this.logoUrl = img;
        });
        // 不是自建站，拼接绝对路径访问链接
        if (this.merSourceType != 1) {
          this.form.patchValue({ merLogo: this.FILE_URL + info.file.response['return_data'][0]});
        } else {
          this.form.patchValue({ merLogo: info.file.response['return_data'][0]});
        }
        break;
      case 'error':
        this.message.error('网络错误！');
        this.loading = false;
        break;
    }
  }

  beforeUpload = (file: NzUploadFile, _fileList: NzUploadFile[]) => {
    return new Observable((observer: Observer<boolean>) => {
      const isJpgOrPng = file.type === 'image/jpeg' || file.type === 'image/png';
      if (!isJpgOrPng) {
        this.message.error('只能上传JPG文件!');
        observer.complete();
        return;
      }
      const isLt2M = file.size! / 1024 / 1024 < 2;
      if (!isLt2M) {
        this.message.error('图片必须小于2MB!');
        observer.complete();
        return;
      }
      observer.next(isJpgOrPng && isLt2M);
      observer.complete();
    });
  };
}
