import { Component } from '@angular/core';
import {FormGroup, FormsModule, NonNullableFormBuilder, ReactiveFormsModule, Validators} from "@angular/forms";
import {MerChainBrandService} from "../../../services/merchant/mer-chain-brand.service";
import {DatePipe, NgForOf, NgIf} from "@angular/common";
import {DictionaryPipe} from "../../../pipes/common/dictionary.pipe";
import {NzButtonComponent} from "ng-zorro-antd/button";
import {
  NzCellFixedDirective,
  NzTableCellDirective,
  NzTableComponent, NzTableModule,
  NzTbodyComponent, NzTheadComponent,
  NzThMeasureDirective, NzTrDirective
} from "ng-zorro-antd/table";
import {NzColDirective, NzRowDirective} from "ng-zorro-antd/grid";
import {NzDividerComponent} from "ng-zorro-antd/divider";
import {NzDropDownADirective, NzDropDownDirective, NzDropdownMenuComponent} from "ng-zorro-antd/dropdown";
import {NzFormControlComponent, NzFormDirective, NzFormItemComponent, NzFormLabelComponent} from "ng-zorro-antd/form";
import {NzIconDirective} from "ng-zorro-antd/icon";
import {NzInputDirective} from "ng-zorro-antd/input";
import {NzMenuDirective, NzMenuItemComponent} from "ng-zorro-antd/menu";
import {NzOptionComponent, NzSelectComponent} from "ng-zorro-antd/select";
import {NzModalModule} from "ng-zorro-antd/modal";
import {NzFlexDirective} from "ng-zorro-antd/flex";
import {NzDescriptionsModule} from "ng-zorro-antd/descriptions";
import {NzUploadComponent} from "ng-zorro-antd/upload";
import {NzAvatarModule} from "ng-zorro-antd/avatar";
import {NzImageModule} from "ng-zorro-antd/image";
import {NzSwitchComponent} from "ng-zorro-antd/switch";
import {NzDatePickerComponent} from "ng-zorro-antd/date-picker";
import {NzMessageService} from "ng-zorro-antd/message";

@Component({
  selector: 'app-mer-chain-brand-list',
  standalone: true,
  imports: [
    DatePipe,
    DictionaryPipe,
    FormsModule,
    NgForOf,
    NgIf,
    NzButtonComponent,
    NzCellFixedDirective,
    NzColDirective,
    NzDividerComponent,
    NzDropDownADirective,
    NzDropDownDirective,
    NzDropdownMenuComponent,
    NzFormControlComponent,
    NzFormDirective,
    NzFormItemComponent,
    NzFormLabelComponent,
    NzIconDirective,
    NzInputDirective,
    NzMenuDirective,
    NzMenuItemComponent,
    NzOptionComponent,
    NzRowDirective,
    NzSelectComponent,
    NzTableCellDirective,
    NzTableComponent,
    NzTbodyComponent,
    NzThMeasureDirective,
    NzTheadComponent,
    NzTrDirective,
    ReactiveFormsModule,
    NzTableModule,
    NzModalModule,
    NzFlexDirective,
    NzDescriptionsModule,
    NzUploadComponent,
    NzAvatarModule,
    NzImageModule,
    NzSwitchComponent,
    NzDatePickerComponent,
  ],
  templateUrl: './mer-chain-brand-list.component.html',
  styleUrl: './mer-chain-brand-list.component.less'
})
export class MerChainBrandListComponent {
  // 表单页数
  tablePageNum = 1;
  // 每页数量
  tablePageSize = 10;
  // 表单数据
  tableData: any = {
    total: 0,
    list: [],
  };
  // 搜索表单
  searchForm: FormGroup;
  // 更多搜索条件
  isCollapse = false;
  // 编辑品牌表单
  editChainBrandForm: FormGroup;
  editChainBrandModel = false;
  constructor(private fb: NonNullableFormBuilder,
              private message: NzMessageService,
              private merChainBrandService: MerChainBrandService) {
    // 初始化搜索框
    this.searchForm = this.fb.group({
      name: [''],
      contactsName: [''],
      contactsTelephone: [''],
    });

    // 初始化表单
    this.editChainBrandForm = this.fb.group({
      id: [null],
      name: [null, [Validators.required]],
      contactsName: [null, [Validators.required]],
      contactsTelephone: [null, [Validators.required]],
    });

    this.queryData();
  }

  /**
   * 获取数据
   */
  queryData() {
    this.searchForm.value.pageNum = this.tablePageNum;
    this.searchForm.value.pageSize = this.tablePageSize;
    this.searchForm.value.time = new Date().getTime();
    this.merChainBrandService.getList(this.searchForm.value, (data: any) => {
      if (data['return_code'] == '000000') {
        this.tableData = data['return_data'];
      }
    });
  }

  /**
   * 搜索表单提交
   */
  searchFormSubmit(): void {
    this.tablePageNum = 1;
    this.queryData();
  }

  /**
   * 搜索表单重置
   */
  searchFormReset(): void {
    this.searchForm.reset();
  }

  /**
   * 打开编辑连锁品牌模态框
   * @param data
   */
  showChainBrandModel(data: any) {
    this.editChainBrandForm.patchValue(data);
    this.editChainBrandModel = true;
  }

  /**
   * 提交表单
   */
  submitChainBrandModel() {
    if (this.editChainBrandForm.valid) {
      let param = this.editChainBrandForm.value;
      this.merChainBrandService.editChainBrand(param, (data: any) => {
        if (data['return_code'] == '000000') {
          this.message.create('success', '操作成功');
          this.queryData();
          // 关闭弹窗
          this.closeChainBrandModel();
        } else {
          this.message.create('error', data['return_msg']);
        }
      });
    } else {
      Object.values(this.editChainBrandForm.controls).forEach(control => {
        if (control.invalid) {
          control.markAsDirty();
          control.updateValueAndValidity({ onlySelf: true });
        }
      });
    }
  }

  /**
   * 关闭编辑连锁品牌模态框
   */
  closeChainBrandModel() {
    this.editChainBrandForm.reset();
    this.editChainBrandModel = false;
  }

}
