import {Component, ElementRef, ViewChild} from '@angular/core';
import {MerStaffService} from "../../../services/merchant/mer-staff.service";
import {FormGroup, FormsModule, NonNullableFormBuilder, ReactiveFormsModule, Validators} from "@angular/forms";
import {NzMessageService} from "ng-zorro-antd/message";
import {BrowserStorageService} from "../../../utils/localStorage.service";
import {NzModalModule, NzModalService} from "ng-zorro-antd/modal";
import {CommonService} from "../../../services/common/common.service";
import {DATA} from "../../../data/login/localStorage.namespace";
import {NzInputDirective} from "ng-zorro-antd/input";
import {DictionaryPipe} from "../../../pipes/common/dictionary.pipe";
import {DatePipe, NgForOf, NgIf} from "@angular/common";
import {NzButtonComponent} from "ng-zorro-antd/button";
import {
  NzCellFixedDirective,
  NzTableCellDirective,
  NzTableComponent, NzTableModule,
  NzTbodyComponent, NzTheadComponent,
  NzThMeasureDirective, NzTrDirective
} from "ng-zorro-antd/table";
import {NzColDirective, NzRowDirective} from "ng-zorro-antd/grid";
import {NzDividerComponent} from "ng-zorro-antd/divider";
import {NzDropDownADirective, NzDropDownDirective, NzDropdownMenuComponent} from "ng-zorro-antd/dropdown";
import {NzFormControlComponent, NzFormDirective, NzFormItemComponent, NzFormLabelComponent} from "ng-zorro-antd/form";
import {NzIconDirective} from "ng-zorro-antd/icon";
import {NzMenuDirective, NzMenuItemComponent} from "ng-zorro-antd/menu";
import {NzOptionComponent, NzSelectComponent} from "ng-zorro-antd/select";
import {NzFlexDirective} from "ng-zorro-antd/flex";
import {NzDescriptionsModule} from "ng-zorro-antd/descriptions";
import {NzUploadComponent} from "ng-zorro-antd/upload";
import {NzAvatarModule} from "ng-zorro-antd/avatar";
import {NzImageModule} from "ng-zorro-antd/image";
import {NzSwitchComponent} from "ng-zorro-antd/switch";
import {NzDatePickerComponent, NzRangePickerComponent} from "ng-zorro-antd/date-picker";
import {NzRadioButtonDirective, NzRadioComponent, NzRadioGroupComponent} from "ng-zorro-antd/radio";
import {NzToolTipModule} from "ng-zorro-antd/tooltip";
import {NzTabsModule} from "ng-zorro-antd/tabs";
import {NzTagModule} from "ng-zorro-antd/tag";
import {NzCardModule} from "ng-zorro-antd/card";
import {NzInputNumberModule} from "ng-zorro-antd/input-number";
import {NzQRCodeModule} from "ng-zorro-antd/qr-code";
import {RouterLink} from "@angular/router";
import {NzTypographyComponent} from "ng-zorro-antd/typography";

@Component({
  selector: 'app-mer-staff-list',
  standalone: true,
  imports: [
    DatePipe,
    DictionaryPipe,
    FormsModule,
    NgForOf,
    NgIf,
    NzButtonComponent,
    NzCellFixedDirective,
    NzColDirective,
    NzDividerComponent,
    NzDropDownADirective,
    NzDropDownDirective,
    NzDropdownMenuComponent,
    NzFormControlComponent,
    NzFormDirective,
    NzFormItemComponent,
    NzFormLabelComponent,
    NzIconDirective,
    NzInputDirective,
    NzMenuDirective,
    NzMenuItemComponent,
    NzOptionComponent,
    NzRowDirective,
    NzSelectComponent,
    NzTableCellDirective,
    NzTableComponent,
    NzTbodyComponent,
    NzThMeasureDirective,
    NzTheadComponent,
    NzTrDirective,
    ReactiveFormsModule,
    NzTableModule,
    NzModalModule,
    NzFlexDirective,
    NzDescriptionsModule,
    NzUploadComponent,
    NzAvatarModule,
    NzImageModule,
    NzSwitchComponent,
    NzDatePickerComponent,
    NzRadioButtonDirective,
    NzRadioComponent,
    NzRadioGroupComponent,
    NzRangePickerComponent,
    NzToolTipModule,
    NzTabsModule,
    NzTagModule,
    NzCardModule,
    NzInputNumberModule,
    NzQRCodeModule,
    RouterLink,
    NzTypographyComponent
  ],
  templateUrl: './mer-staff-list.component.html',
  styleUrl: './mer-staff-list.component.less'
})
export class MerStaffListComponent {
// 表单页数
  tablePageNum = 1;
  // 每页数量
  tablePageSize = 10;
  // 表单数据
  tableData: any = {
    total: 0,
    list: [],
  };
  merNo = null;
  // 搜索表单
  searchForm: FormGroup;
  // 地区
  regionArray: any = [];
  // 编辑任务表单
  editStaffForm: FormGroup;
  editStaffModal = false;
  // 加油员类型
  staffPositionTypeArray = new DictionaryPipe().getDictionaryList('GAS_STAFF_POSITION_TYPE');
  qrCodeVisible = false;
  staffData: any = {};
  constructor(private fb: NonNullableFormBuilder,
              private message: NzMessageService,
              private storage: BrowserStorageService,
              private merStaffService: MerStaffService,
              private commonService: CommonService,
              private modal: NzModalService) {
    this.merNo = this.storage.get(DATA)['merchant']['merNo'];

    // 获取地区
    this.commonService.getRegion('',(data: any) => {
      if (data['return_code'] == '000000') {
        this.regionArray = data['return_data'];
      }
    });
    // 初始化搜索框
    this.searchForm = this.fb.group({
      positionType: [null],
      name: [null],
      telephone: [null],
    });

    this.editStaffForm = this.fb.group({
      id: [''],
      positionType: ['1', [Validators.required]],
      name: ['', [Validators.required]],
      telephone: ['', [Validators.required]],
    });
    // 查询数据
    this.queryData();
  }

  /**
   * 获取数据
   */
  queryData() {
    this.searchForm.value.pageNum = this.tablePageNum;
    this.searchForm.value.pageSize = this.tablePageSize;
    this.searchForm.value.time = new Date().getTime();
    this.merStaffService.getStaffList(this.searchForm.value, (data: any) => {
      if (data['return_code'] == '000000') {
        this.tableData = data['return_data'];
      }
    });
  }

  /**
   * 搜索表单提交
   */
  searchFormSubmit(): void {
    this.tablePageNum = 1;
    this.queryData();
  }

  /**
   * 搜索表单重置
   */
  searchFormReset(): void {
    this.searchForm.reset();
  }

  /**
   * 删除
   */
  delStaff(id: number) {
    this.modal.confirm({
      nzTitle: '提示',
      nzContent: '确定删除吗？',
      nzOnOk: () =>
        this.merStaffService.delStaff({staffId: id}, (data: any) => {
          if (data['return_code'] == '000000') {
            // 刷新数据
            this.queryData();
            this.message.create('success', '操作成功');
          } else {
            this.message.create('error', data['return_msg']);
          }
        })
    });
  }

  /**
   * 恢复
   */
  recover(id: number) {
    this.modal.confirm({
      nzTitle: '提示',
      nzContent: '确定恢复账户状态吗？',
      nzOnOk: () =>
        this.merStaffService.recover({staffId: id}, (data: any) => {
          if (data['return_code'] == '000000') {
            // 刷新数据
            this.queryData();
            this.message.create('success', '操作成功');
          } else {
            this.message.create('error', data['return_msg']);
          }
        })
    });
  }

  /**
   * 禁用
   */
  disabled(id: number) {
    this.modal.confirm({
      nzTitle: '提示',
      nzContent: '确定禁用账户吗？',
      nzOnOk: () =>
        this.merStaffService.disabled({staffId: id}, (data: any) => {
          if (data['return_code'] == '000000') {
            // 刷新数据
            this.queryData();
            this.message.create('success', '操作成功');
          } else {
            this.message.create('error', data['return_msg']);
          }
        })
    });
  }

  /**
   * 打开编辑任务模态框
   */
  showEditStaffModal(data:any) {
    if (data != null) {
      data['positionType'] = String(data['positionType']);
      this.editStaffForm.patchValue(data);
    }
    this.editStaffModal = true;
  }

  /**
   * 提交数据
   */
  submitData() {
    if (this.editStaffForm.valid) {
      if (this.editStaffForm.controls['id'].value == null) {
        this.merStaffService.addGasStaff(this.editStaffForm.value, (data: any) => {
          if (data['return_code'] == '000000') {
            this.message.create('success', '操作成功');
            // 刷新数据
            this.queryData();
            // 关闭弹窗
            this.closeEditStaffModal();
          } else {
            this.message.create('error', data['return_msg']);
          }
        });
      } else {
        this.merStaffService.updateGasStaff(this.editStaffForm.value, (data: any) => {
          if (data['return_code'] == '000000') {
            this.message.create('success', '操作成功');
            // 刷新数据
            this.queryData();
            // 关闭弹窗
            this.closeEditStaffModal();
          } else {
            this.message.create('error', data['return_msg']);
          }
        });
      }
    } else {
      Object.values(this.editStaffForm.controls).forEach(control => {
        if (control.invalid) {
          control.markAsDirty();
          control.updateValueAndValidity({ onlySelf: true });
        }
      });
    }
  }

  /**
   * 关闭编辑任务模态框
   */
  closeEditStaffModal() {
    this.editStaffForm.reset();
    this.editStaffModal = false;
  }

  /**
   * 展示二维码
   * @param merNo
   */
  showQrCode(data: any) {
    this.staffData = data;
    this.qrCodeVisible = true;
  }

  /**
   * 关闭二维码展示
   */
  closeQrCode() {
    this.qrCodeVisible = false;
  }

  /**
   * 下载二维码
   * @param type
   */
  @ViewChild('download', { static: false }) download!: ElementRef;
  downloadMerQrCode(type: number) {
    const canvas = document.getElementById('download'+(type==1?'H5':'Wx'))?.querySelector<HTMLCanvasElement>('canvas');
    if (canvas) {
      this.download.nativeElement.href = canvas.toDataURL('image/png');
      this.download.nativeElement.download = new Date().getTime();
      const event = new MouseEvent('click');
      this.download.nativeElement.dispatchEvent(event);
    }
  }
}
