import {Component, ElementRef, ViewChild} from '@angular/core';
import {DatePipe, NgForOf, NgIf} from "@angular/common";
import {DictionaryPipe} from "../../../pipes/common/dictionary.pipe";
import {FormsModule, NonNullableFormBuilder, ReactiveFormsModule} from "@angular/forms";
import {NzButtonComponent} from "ng-zorro-antd/button";
import {
  NzCellFixedDirective,
  NzTableCellDirective,
  NzTableComponent, NzTableModule,
  NzTbodyComponent, NzTheadComponent,
  NzThMeasureDirective, NzTrDirective
} from "ng-zorro-antd/table";
import {NzColDirective, NzRowDirective} from "ng-zorro-antd/grid";
import {NzDividerComponent} from "ng-zorro-antd/divider";
import {NzDropDownADirective, NzDropDownDirective, NzDropdownMenuComponent} from "ng-zorro-antd/dropdown";
import {NzFormControlComponent, NzFormDirective, NzFormItemComponent, NzFormLabelComponent} from "ng-zorro-antd/form";
import {NzIconDirective} from "ng-zorro-antd/icon";
import {NzInputDirective} from "ng-zorro-antd/input";
import {NzMenuDirective, NzMenuItemComponent} from "ng-zorro-antd/menu";
import {NzOptionComponent, NzSelectComponent} from "ng-zorro-antd/select";
import {NzModalModule, NzModalService} from "ng-zorro-antd/modal";
import {NzFlexDirective} from "ng-zorro-antd/flex";
import {NzDescriptionsModule} from "ng-zorro-antd/descriptions";
import {NzUploadComponent} from "ng-zorro-antd/upload";
import {NzAvatarModule} from "ng-zorro-antd/avatar";
import {NzImageModule} from "ng-zorro-antd/image";
import {NzSwitchComponent} from "ng-zorro-antd/switch";
import {NzDatePickerComponent} from "ng-zorro-antd/date-picker";
import {NzInputNumberModule} from "ng-zorro-antd/input-number";
import {WeekPipe} from "../../../pipes/common/week.pipe";
import {NzMessageService} from "ng-zorro-antd/message";
import {BrowserStorageService} from "../../../utils/localStorage.service";
import {CommonService} from "../../../services/common/common.service";
import {DATA} from "../../../data/login/localStorage.namespace";
import {MerService} from "../../../services/merchant/mer.service";
import {NzTabComponent, NzTabSetComponent} from "ng-zorro-antd/tabs";
import {NzCardComponent} from "ng-zorro-antd/card";
import {NzQRCodeComponent} from "ng-zorro-antd/qr-code";

@Component({
  selector: 'app-qr-code-list',
  standalone: true,
  imports: [
    DatePipe,
    DictionaryPipe,
    FormsModule,
    NgForOf,
    NgIf,
    NzButtonComponent,
    NzCellFixedDirective,
    NzColDirective,
    NzDividerComponent,
    NzDropDownADirective,
    NzDropDownDirective,
    NzDropdownMenuComponent,
    NzFormControlComponent,
    NzFormDirective,
    NzFormItemComponent,
    NzFormLabelComponent,
    NzIconDirective,
    NzInputDirective,
    NzMenuDirective,
    NzMenuItemComponent,
    NzOptionComponent,
    NzRowDirective,
    NzSelectComponent,
    NzTableCellDirective,
    NzTableComponent,
    NzTbodyComponent,
    NzThMeasureDirective,
    NzTheadComponent,
    NzTrDirective,
    ReactiveFormsModule,
    NzTableModule,
    NzModalModule,
    NzFlexDirective,
    NzDescriptionsModule,
    NzUploadComponent,
    NzAvatarModule,
    NzImageModule,
    NzSwitchComponent,
    NzDatePickerComponent,
    NzInputNumberModule,
    WeekPipe,
    NzTabSetComponent,
    NzTabComponent,
    NzCardComponent,
    NzQRCodeComponent
  ],
  templateUrl: './qr-code-list.component.html',
  styleUrl: './qr-code-list.component.less'
})
export class QrCodeListComponent {
// 表单数据
  tableData: any = [];
  // 商户号
  merNo = null;

  merQrCodeData: any = [];
  constructor(private fb: NonNullableFormBuilder,
              private message: NzMessageService,
              private storage: BrowserStorageService,
              private merService: MerService,
              private commonService: CommonService,
              private modal: NzModalService) {
    this.merNo = this.storage.get(DATA)['merchant']['merNo'];
    this.merService.queryQrCodeList(this.merNo, (data: any) => {
      if (data['return_code'] == '000000') {
        this.merQrCodeData = data['return_data'];
      } else {
        this.message.error(data['return_msg']);
      }
    });
  }


  /**
   * 下载二维码
   * @param type
   */
  @ViewChild('download', { static: false }) download!: ElementRef;
  downloadMerQrCode(type: number) {
    const canvas = document.getElementById('download'+(type==1?'H5':'Wx'))?.querySelector<HTMLCanvasElement>('canvas');
    if (canvas) {
      this.download.nativeElement.href = canvas.toDataURL('image/png');
      this.download.nativeElement.download = new Date().getTime();
      const event = new MouseEvent('click');
      this.download.nativeElement.dispatchEvent(event);
    }
  }

}
