import { Component } from '@angular/core';
import {FormGroup, FormsModule, NonNullableFormBuilder, ReactiveFormsModule, Validators} from "@angular/forms";
import {DictionaryPipe} from "../../../pipes/common/dictionary.pipe";
import {NzMessageService} from "ng-zorro-antd/message";
import {BrowserStorageService} from "../../../utils/localStorage.service"
import {CommonService} from "../../../services/common/common.service";
import {NzModalModule, NzModalService} from "ng-zorro-antd/modal";
import {DatePipe, NgForOf, NgIf} from "@angular/common";
import {NzButtonComponent} from "ng-zorro-antd/button";
import {
  NzCellFixedDirective,
  NzTableCellDirective,
  NzTableComponent, NzTableModule,
  NzTbodyComponent, NzTheadComponent,
  NzThMeasureDirective, NzTrDirective
} from "ng-zorro-antd/table";
import {NzColDirective, NzRowDirective} from "ng-zorro-antd/grid";
import {NzDividerComponent} from "ng-zorro-antd/divider";
import {NzDropDownADirective, NzDropDownDirective, NzDropdownMenuComponent} from "ng-zorro-antd/dropdown";
import {NzFormControlComponent, NzFormDirective, NzFormItemComponent, NzFormLabelComponent} from "ng-zorro-antd/form";
import {NzIconDirective} from "ng-zorro-antd/icon";
import {NzInputDirective} from "ng-zorro-antd/input";
import {NzMenuDirective, NzMenuItemComponent} from "ng-zorro-antd/menu";
import {NzOptionComponent, NzSelectComponent} from "ng-zorro-antd/select";
import {NzFlexDirective} from "ng-zorro-antd/flex";
import {NzDescriptionsModule} from "ng-zorro-antd/descriptions";
import {NzUploadComponent} from "ng-zorro-antd/upload";
import {NzAvatarModule} from "ng-zorro-antd/avatar";
import {NzImageModule} from "ng-zorro-antd/image";
import {NzSwitchComponent} from "ng-zorro-antd/switch";
import {NzDatePickerComponent} from "ng-zorro-antd/date-picker";
import {NzInputNumberModule} from "ng-zorro-antd/input-number";
import {WeekPipe} from "../../../pipes/common/week.pipe";
import {SpreadUserService} from "../../../services/spread/spread-user.service";
import {SpreadUserStatusPipe} from "../../../pipes/spread/spread-user-status.pipe";
import {NzStatisticModule} from "ng-zorro-antd/statistic";
import {SpreadUserAccountRecordComponent} from "../spread-user-account-record/spread-user-account-record.component";
import {SpreadCommissionComponent} from "../spread-commission/spread-commission.component";

@Component({
  selector: 'app-spread-user-list',
  standalone: true,
  imports: [
    DatePipe,
    DictionaryPipe,
    FormsModule,
    NgForOf,
    NgIf,
    NzButtonComponent,
    NzCellFixedDirective,
    NzColDirective,
    NzDividerComponent,
    NzDropDownADirective,
    NzDropDownDirective,
    NzDropdownMenuComponent,
    NzFormControlComponent,
    NzFormDirective,
    NzFormItemComponent,
    NzFormLabelComponent,
    NzIconDirective,
    NzInputDirective,
    NzMenuDirective,
    NzMenuItemComponent,
    NzOptionComponent,
    NzRowDirective,
    NzSelectComponent,
    NzTableCellDirective,
    NzTableComponent,
    NzTbodyComponent,
    NzThMeasureDirective,
    NzTheadComponent,
    NzTrDirective,
    ReactiveFormsModule,
    NzTableModule,
    NzModalModule,
    NzFlexDirective,
    NzDescriptionsModule,
    NzUploadComponent,
    NzAvatarModule,
    NzImageModule,
    NzSwitchComponent,
    NzDatePickerComponent,
    NzInputNumberModule,
    WeekPipe,
    SpreadUserStatusPipe,
    NzStatisticModule,
    SpreadCommissionComponent,
    SpreadUserAccountRecordComponent,
  ],
  templateUrl: './spread-user-list.component.html',
  styleUrl: './spread-user-list.component.less'
})
export class SpreadUserListComponent {
  // 表单页数
  tablePageNum = 1;
  // 每页数量
  tablePageSize = 10;
  // 表单数据
  tableData: any = [];
  // 搜索表单
  searchForm: FormGroup;

  countDataObj: any = {
    totalAmount: 0,
    sysSperadAmount: 0,
    cashOutAmount: 0,
    surplusAmount: 0,
  };

  rechargeModal = false;
  rechargeForm: FormGroup;

  commissionModal = false;
  userId = null;

  settleModal = false;
  constructor(private fb: NonNullableFormBuilder,
              private message: NzMessageService,
              private storage: BrowserStorageService,
              private spreadUserService: SpreadUserService,
              private commonService: CommonService,
              private modal: NzModalService) {
    // 初始化搜索框
    this.searchForm = this.fb.group({
      phone: [null],
    });
    this.rechargeForm = this.fb.group({
      amount: ['',[Validators.required]],
    });

    this.queryCountCommission();
    // 查询数据
    this.queryData();
  }

  /**
   * 查询佣金统计
   */
  queryCountCommission() {
    // 佣金情况
    this.spreadUserService.countCommission((data: any) => {
      if (data['return_code'] == '000000'){
        this.countDataObj = data['return_data'];
      }
    })
  }
  /**
   * 获取数据
   */
  queryData() {
    this.searchForm.value.pageNum = this.tablePageNum;
    this.searchForm.value.pageSize = this.tablePageSize;
    this.searchForm.value.time = new Date().getTime();
    this.spreadUserService.getUserSpreadList(this.searchForm.value, (data: any) => {
      if (data['return_code'] == '000000') {
        this.tableData = data['return_data'];
      }
    });
  }

  /**
   * 搜索表单提交
   */
  searchFormSubmit(): void {
    this.queryData();
  }

  /**
   * 搜索表单重置
   */
  searchFormReset(): void {
    this.searchForm.reset();
  }

  /**
   * 展示模态框
   */
  showRechargeModal() {
    this.rechargeModal = true;
  }

  /**
   * 提交模态框
   */
  submitRechargeModal() {
    if (this.rechargeForm.valid) {
      this.spreadUserService.recharge(this.rechargeForm.value, (data: any) => {
        if (data['return_code'] == '000000') {
          this.message.create('success', '操作成功');
          // 刷新数据
          this.queryCountCommission();
          // 关闭弹窗
          this.closeRechargeModal();
          // 表单重置
          this.rechargeForm.reset();
        } else {
          this.message.create('error', data['return_msg']);
        }
      });
    } else {
      Object.values(this.rechargeForm.controls).forEach(control => {
        if (control.invalid) {
          control.markAsDirty();
          control.updateValueAndValidity({ onlySelf: true });
        }
      });
    }
  }

  /**
   * 关闭模态框
   */
  closeRechargeModal() {
    this.rechargeModal = false;
  }

  /**
   * 冻结账户
   * @param id
   */
  freezeUserSpread(id: number) {
    this.modal.confirm({
      nzTitle: '提示',
      nzContent: '确定冻结用户推广账户吗？',
      nzOnOk: () =>
        this.spreadUserService.freezeUserSpread({userId: id}, (data: any) => {
          if (data['return_code'] == '000000') {
            // 刷新数据
            this.queryData();
            this.message.create('success', '操作成功');
          } else {
            this.message.create('error', data['return_msg']);
          }
        })
    });
  }

  /**
   * 恢复账户
   * @param id
   */
  unfreezeUserSpread(id: number) {
    this.modal.confirm({
      nzTitle: '提示',
      nzContent: '确定恢复用户推广账户状态吗？',
      nzOnOk: () =>
        this.spreadUserService.unfreezeUserSpread({userId: id}, (data: any) => {
          if (data['return_code'] == '000000') {
            // 刷新数据
            this.queryData();
            this.message.create('success', '操作成功');
          } else {
            this.message.create('error', data['return_msg']);
          }
        })
    });
  }

  /**
   * 打开佣金明细
   * @param userId
   */
  showCommission(userId: any) {
    this.userId = userId;
    this.commissionModal = true;
  }

  /**
   * 打款结算明细
   * @param userId
   */
  showSettle(userId: any) {
    this.userId = userId;
    this.settleModal = true;
  }
}
